<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Display help </source>
        <translation>顯示說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Back</source>
        <translation>上一步</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>View Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <location filename="../mainwindow.cpp" line="527"/>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Select ISO</source>
        <translation>選擇 ISO 檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;選擇標的 USB 設備 Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;選擇 ISO 檔&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Advanced Options</source>
        <translation>進階選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>即便目標上已有 ext4 檔案系統，仍然製作該檔案系統</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>更新 usb 現場版的時候，保存原本的 boot 目錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>採用 gpt 磁碟區，不採用 msdos 磁碟區</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>GPT partitioning</source>
        <translation>GPT 磁碟區</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>更新檔案（只是更新既有的 usb 現場版）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>不取代原本的 syslinux 檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Keep syslinux files</source>
        <translation>保留 syslinux 檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Ignore USB/removable check</source>
        <translation>跳過不檢查 USB 與可抽取之設備</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Temporarily disable automounting</source>
        <translation>暫時凍結自動掛載功能</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>設定 pmbr_boot 磁碟旗標（無法透過 UEFI 開機）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>ESP (uefi) 磁碟區大小：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Verbosity (less to more):</source>
        <translation>詳細程度（由低至高）：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>Make separate data partition (percent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Refresh drive list</source>
        <translation>更新磁碟清單</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Show advanced options</source>
        <translation>顯示進階選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="583"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>唯讀，不可用於持續版的映像檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Percent of USB-device to use:</source>
        <translation>動用 USB 設備的多少百分比：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <source>Label ext partition:</source>
        <translation>ext 磁碟區的標籤：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>一切會影響到 usb 設備的命令，均不執行</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Dry run (no change to system)</source>
        <translation>排演（不動到系統）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>從掛載在系統上的現場版 usb，或者 iso 檔，進行複製。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Clone a mounted live system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>進行設定，以從加密的磁碟區開機；首次開機時，會請你輸入密碼（pass phrase）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Encrypt</source>
        <translation>加密</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Clone running live system</source>
        <translation>複製正在運行的現場系統</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="118"/>
        <location filename="../mainwindow.cpp" line="336"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Failure</source>
        <translation>失敗</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>讀取的來源與寫入的目標乃是同一個設備，請重新選擇。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>MX Live Usb Maker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>LiveUSB creation successful!</source>
        <translation>現場版 USB 製作成功！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>製作現場版 USB 的程序發生錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>Please select a USB device to write to</source>
        <translation>請選擇要寫入哪一個 USB 設備</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="397"/>
        <source>These actions will destroy all data on 

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Do you wish to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>About %1</source>
        <translation>大約 %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>本程式可以製作現場版 usb，其資料來源可以是 iso 檔、另外一個現場版 usb、現場版 cd/dvd、正在運行的系統。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>%1 License</source>
        <translation>%1 許可</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>%1 Help</source>
        <translation>%1 幫助</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>選擇要用哪個 ISO 檔來寫入 USB 設備</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>Select Source Directory</source>
        <translation>選擇資料來源目錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>找不到 %1/antiX/linuxfs 檔案</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Hide advanced options</source>
        <translation>隱藏進階選項</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Select Source</source>
        <translation>選擇來源</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Select ISO file</source>
        <translation>選擇 ISO 檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>clone</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>變更紀錄</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>本程式可以製作現場版 usb，其資料來源可以是 iso 檔、另外一個現場版 usb、現場版 cd/dvd、正在運行的系統。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>[filename]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>本程式必須以 root 身份來執行。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
